import setuptools


setuptools.setup(
    name="dennis-systems-core",
    version="0.1.4",
    author="Denis Oleshko",
    author_email="dennis.oleshko@gmail.com",
    description="Authorization model",
    long_description='All about authorization',
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)